quran library
Classes
- AssetsPath
- AyahDownloadManagerTheme
- مزود نمط قسمَي الأعلى/الأسفل (Top/Bottom)
- AyahLongClickTheme
- مزود نمط حوار الضغط المطوّل على الآية
- AyahMenuDialog
- A dialog displayed on long click of an Ayah to provide options like bookmarking and copying text.
- AyahMenuStyle
- نمط مخصص لحوار الضغط المطوّل على الآية (AyahLongClickDialog).
- AyahModel
- موديل موحد للآية في القرآن يدعم كل من بيانات الخطوط الأصلية والمنزلة Unified Ayah model for both original and downloaded fonts data
- BannerStyle
- BasmalaStyle
- A class that represents the style for Basmala text in the application.
- BasmallahWidget
- A widget that displays the Basmallah (بِسْمِ ٱللَّٰهِ ٱلرَّحْمَٰنِ ٱلرَّحِيمِ).
- BookmarkModel
- A model class that represents a single bookmark in the Quran.
- BookmarksAyahs
- A model class that represents a single bookmark in the Quran.
- BookmarksCtrl
- Controller that handles the bookmarks of the user.
- BookmarksTabStyle
- فئة لتخصيص أنماط واجهة تبويب الفواصل Class for customizing Bookmarks Tab styles
- BookmarksTabTheme
- مزود نمط تبويب العلامات المرجعية (Bookmarks)
- BuildBottomSection
- BuildTopSection
- CurvyArrowButton
- CurvyArrowPainter
- DataSource
- Data source configuration for Quran recitations
- DownloadFontsDialogStyle
- A class that defines the style for the download fonts dialog.
- FontsDownloadDialog
- FontsDownloadWidget
- GetSingleAyah
- IndexTabStyle
- نمط مخصص لتبويب الفهرس (السور/الأجزاء) داخل شريط القرآن. يتيح تخصيص الألوان والأبعاد والأنماط النصية والعناوين.
- IndexTabTheme
- مزود نمط تبويب الفهرس
- JumpingPageControllerWidget
- LineModel
- هذا الموديل يمثل سطر في صفحة القرآن ويحتوي على قائمة من الآيات الموحدة This model represents a line in a Quran page and contains a list of unified ayahs
- PageBuild
- PageFontSizeHelper
- Helpers to compute dynamic font sizes for Quran pages across devices.
- PageViewBuild
- PatchedPreloadPageView
-
نسخة مُعدّلة من
PreloadPageViewتدعم padEnds. - QiraatAyahWords
- QiraatSurahWords
- QiraatWordInfo
- QpcHafsWordByWordAssetsLoader
- QpcHafsWordByWordStore
- QpcV4AssetsLoader
- QpcV4AssetsStore
- QpcV4AyahInfoLine
- QpcV4AyahLineBlock
- QpcV4AyahSegment
- QpcV4BasmallahBlock
- QpcV4PageRenderer
- QpcV4RenderBlock
- QpcV4RichTextLine
- QpcV4SurahHeaderBlock
- QpcV4Word
- QpcV4WordSegment
- QuranCtrl
- QuranFontsService
- خدمة تحميل كسول (lazy) وتسجيل خطوط QCF4 المضغوطة (tajweed).
- QuranLibrary
- A class that provides utility functions for interacting with the Quran library.
- QuranLibraryScreen
- A widget that displays the Quran library screen.
- QuranLibraryTheme
- غلاف مركزي يحقن مزوِّدات أنماط متعددة بشكل مستقل لتقليل إعادة البناء
- QuranOrTenRecitationsTabBar
- QuranPageModel
- هذا الموديل يمثل صفحة من صفحات القرآن ويحتوي على قائمة من الآيات (AyahModel) والأسطر (LineModel) This model represents a Quran page and contains a list of ayahs (AyahModel) and lines (LineModel)
- QuranPagesScreen
- شاشة لعرض صفحة واحدة أو مجموعة صفحات محددة من المصحف
- QuranRepository
- A repository class for managing Quran-related data.
- QuranState
- QuranTopBarStyle
- Style configuration for Quran Top Bar (previously DefaultDrawer) Allows customizing colors, texts, spacings, and icons
- QuranTopBarTheme
- مزود نمط الشريط العلوي للمصحف
- SajdaFontsModel
- SearchTabStyle
- نمط مخصص لتبويب البحث داخل مكتبة القرآن.
- SearchTabTheme
- مزود نمط تبويب البحث
- SnackBarStyle
- نمط مخصص للـ SnackBar
- SnackBarTheme
- مزود نمط SnackBar
- SurahCtrl
- كنترولر مخصص لعرض سورة واحدة بنفس تصميم QuranCtrl Dedicated controller for displaying a single surah with the same design as QuranCtrl
- SurahDisplayScreen
- شاشة لعرض سورة واحدة فقط باستخدام SurahCtrl Screen for displaying a single surah only using SurahCtrl
- SurahHeaderWidget
- SurahInfoStyle
- SurahInfoTheme
- مزود نمط معلومات السورة (الأسفلية)
- SurahModel
- موديل موحد للسورة يربط مع AyahModel Unified Surah model linked with AyahModel
- SurahNamesModel
- SurahNameStyle
- A class that defines the style for a Surah name.
- SurahPageViewBuild
- ويدجت لعرض صفحة واحدة ضمن شاشة "سورة واحدة" فقط.
- SurahResponseModel
- SuraJsonFilesService
-
خدمة صغيرة لإدارة ملفات
sura_###.json: - TafsirTheme
- مزود نمط التفسير
- TajweedButtonWidget
- TajweedMenuStyle
- نمط تخصيص نافذة/قائمة أحكام التجويد.
- TajweedMenuTheme
- مزود نمط قائمة أحكام التجويد
- TajweedMenuWidget
- TajweedRuleModel
- TapLongPressRecognizer
- Recognizer يدعم ضغط مطوّل قصير (للكلمة) وضغط مطوّل أطول (للآية) داخل TextSpan.
- TextScaleRichTextBuild
- ToastUtils
- TopAndBottomWidget
- ويدجت لعرض محتوى السورة المخصصة مع المعلومات المطلوبة Widget for displaying custom surah content with required information
- TopBottomQuranStyle
- نمط مخصص لقسمَي أعلى/أسفل الصفحة (Top/Bottom) في المصحف.
- TopBottomTheme
- مزود نمط قسمَي الأعلى/الأسفل (Top/Bottom)
- WordInfoBottomSheetStyle
- Style configuration for Word Info bottom sheet.
- WordInfoCtrl
- WordInfoDialogTheme
- مزود نمط حوار معلومات الكلمة (Word Info)
- WordInfoRepository
- WordInfoWidget
- WordRef
- ZipDownloadService
Enums
- DataSourceType
- Data source types for Quran data
- QpcV4LineType
- QuranRecitation
- Quran recitation types with their configurations
- WordInfoKind
Extensions
- ContextExtensions on BuildContext
- Extension on BuildContext to provide additional utility methods.
- ConvertArabicToEnglishNumbersExtension on String
- Extension to convert Arabic numerals to English numerals and vice versa.
- ConvertNumberExtension on String
-
An extension on the
Stringclass to convert numbers in the string according to the specified language code. - FontsExtension on QuranCtrl
- Extension to handle font-related operations for the QuranCtrl class.
- FontSizeExtension on Widget
- QuranGetters on QuranCtrl
- Extensions on QuranCtrl that provides getters for QuranCtrl's properties.
- SajdaExtension on Widget
- An extension on the Widget class to provide additional functionality related to Sajda (prostration) in the context of the Quran library.
-
SplitBetweenExtension
on List<
T> - StringExtension on String
- StringExtensions on String
- Extension on the String class to provide additional utility methods.
- SurahInfoExtension on void
-
An extension on the
voidtype to provide additional functionality related to Surah information. - TextSpanExtension on String
Properties
-
tajweedRules
→ List<
Map< String, dynamic> > -
final
Functions
-
buildMarkedContentSpan(
{required String content, required TextStyle baseStyle, required TextStyle markedStyle, TextStyle? curlyInnerStyle}) → TextSpan - يبني TextSpan مع تمييز (colored) لبعض المقاطع داخل النص.
-
showAyahMenuDialog(
{required BuildContext context, required bool isDark, required AyahModel ayah, required Offset position, required int index, required int pageIndex, TafsirStyle? externalTafsirStyle}) → Future< void> -
showWordInfoBottomSheet(
{required BuildContext context, required WordRef ref, WordInfoKind initialKind = WordInfoKind.recitations, required bool isDark}) → Future< void>
Typedefs
- QpcV4AyahUqResolver = int Function({required int ayahNumber, required int surahNumber})
- QpcV4WordTextResolver = String? Function(QpcV4Word word)
- TopBottomCustomChildBuilder = Widget Function(BuildContext context, int pageIndex)
- ZipDownloadProgressCallback = void Function(double percent)