AyahTafsirInlineStyle class

نمط وضع عرض الآية مع التفسير المدمج

AyahTafsirInlineStyle Customization style for the ayah-with-inline-tafsir display mode.

Constructors

AyahTafsirInlineStyle({Color? backgroundColor, Color? ayahTextColor, double? ayahFontSize, Color? tafsirTextColor, double? tafsirFontSize, Color? tafsirBackgroundColor, Color? dividerColor, double? dividerThickness, int? tafsirMaxLines, double? tafsirCollapsedHeight, String? readMoreText, String? readLessText, Color? readMoreButtonColor, TextStyle? readMoreTextStyle, EdgeInsetsGeometry? ayahPadding, EdgeInsetsGeometry? tafsirPadding, Color? ayahNumberColor, Color? optionsBarBackgroundColor, Color? tafsirSelectorBarColor, Color? tafsirSelectorTextColor, Color? fontSizeIconColor, Widget? fontSizeWidget, Widget? headerWidget, AyahTafsirInlineOptionsBarWidget? optionsBarWidget, IconData? playIconData, Color? playIconColor, double? iconSize, IconData? playAllIconData, Color? playAllIconColor, IconData? copyIconData, Color? copyIconColor, List<int>? bookmarkColorCodes, double? iconHorizontalPadding, IconData? bookmarkIconData, double? tafsirBackgroundBorderRadius})
const
AyahTafsirInlineStyle.defaults({required bool isDark, required BuildContext context})
factory

Properties

ayahFontSize double?
حجم خط الآية
final
ayahNumberColor Color?
لون رقم الآية
final
ayahPadding EdgeInsetsGeometry?
الحشو الداخلي لكل آية
final
ayahTextColor Color?
لون نص الآية
final
backgroundColor Color?
لون خلفية الصفحة
final
bookmarkColorCodes List<int>?
ألوان رموز العلامات المرجعية
final
bookmarkIconData IconData?
أيقونة العلامة المرجعية
final
copyIconColor Color?
لون أيقونة زر نسخ نص الآية
final
copyIconData IconData?
أيقونة زر نسخ نص الآية
final
dividerColor Color?
لون الفاصل بين الآيات
final
dividerThickness double?
سماكة الفاصل
final
fontSizeIconColor Color?
لون أيقونة حجم الخط
final
fontSizeWidget Widget?
عنصر واجهة المستخدم لحجم الخط
final
hashCode int
The hash code for this object.
no setterinherited
headerWidget Widget?
عنصر واجهة المستخدم لرأس قسم آية مع التفسير (مثل اسم المفسر)
final
iconHorizontalPadding double?
الحشو الأفقي للأيقونات
final
iconSize double?
حجم أيقونة زر تشغيل صوت الآية
final
optionsBarBackgroundColor Color?
لون خلفية رقم الآية
final
optionsBarWidget AyahTafsirInlineOptionsBarWidget?
عنصر واجهة المستخدم لشريط خيارات إضافية (مثل مشاركة الآية أو إضافتها للمفضلة)
final
playAllIconColor Color?
لون أيقونة زر تشغيل صوت جميع الآيات
final
playAllIconData IconData?
أيقونة زر تشغيل صوت جميع الآيات
final
playIconColor Color?
لون أيقونة زر تشغيل صوت الآية
final
playIconData IconData?
أيقونة زر تشغيل صوت الآية
final
readLessText String?
نص زر "اقرأ أقل"
final
readMoreButtonColor Color?
لون زر "اقرأ المزيد"
final
readMoreText String?
نص زر "اقرأ المزيد"
final
readMoreTextStyle TextStyle?
نمط نص زر "اقرأ المزيد"
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tafsirBackgroundBorderRadius double?
final
tafsirBackgroundColor Color?
لون خلفية قسم التفسير
final
tafsirCollapsedHeight double?
ارتفاع التفسير في الحالة المقلّصة
final
tafsirFontSize double?
حجم خط التفسير
final
tafsirMaxLines int?
عدد أسطر التفسير في الحالة المقلّصة
final
tafsirPadding EdgeInsetsGeometry?
الحشو الداخلي للتفسير
final
tafsirSelectorBarColor Color?
لون شريط تغيير التفسير العلوي
final
tafsirSelectorTextColor Color?
لون نص شريط تغيير التفسير
final
tafsirTextColor Color?
لون نص التفسير
final

Methods

copyWith({Color? backgroundColor, Color? ayahTextColor, double? ayahFontSize, Color? tafsirTextColor, double? tafsirFontSize, Color? tafsirBackgroundColor, Color? dividerColor, double? dividerThickness, int? tafsirMaxLines, double? tafsirCollapsedHeight, String? readMoreText, String? readLessText, Color? readMoreButtonColor, TextStyle? readMoreTextStyle, EdgeInsetsGeometry? ayahPadding, EdgeInsetsGeometry? tafsirPadding, Color? ayahNumberColor, Color? ayahNumberBackgroundColor, Color? tafsirSelectorBarColor, Color? tafsirSelectorTextColor, Color? fontSizeIconColor, Widget? fontSizeWidget, Widget? headerWidget, AyahTafsirInlineOptionsBarWidget? optionsBarWidget, IconData? playIconData, Color? playIconColor, double? iconSize, IconData? playAllIconData, Color? playAllIconColor, IconData? copyIconData, Color? copyIconColor, List<int>? bookmarkColorCodes, double? iconHorizontalPadding, IconData? bookmarkIconData, double? tafsirBackgroundBorderRadius}) AyahTafsirInlineStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited