bookmarksAyahs property

List<int> get bookmarksAyahs

A list of ayah Ids that have bookmarks.

This list is created by flattening the bookmarks map, which is a map of color codes to lists of BookmarkModels. The list contains the ayah Ids of all the bookmarks, and is used to check if an ayah has a bookmark or not.

Implementation

List<int> get bookmarksAyahs => _bookmarksAyahsCache;