DisplayModeBarStyle class

نمط شريط أزرار أوضاع العرض

DisplayModeBarStyle Customization style for the display mode selector bar.

Constructors

DisplayModeBarStyle({Color? backgroundColor, Color? selectedIconColor, Color? unselectedIconColor, Color? selectedBackgroundColor, double? iconSize, double? borderRadius, EdgeInsetsGeometry? padding, double? spacing, double? elevation, Alignment? position, Color? tooltipBackgroundColor, TextStyle? tooltipTextStyle, bool? showTooltip})
const
DisplayModeBarStyle.defaults({required bool isDark, required BuildContext context})
factory

Properties

backgroundColor Color?
لون خلفية الشريط
final
borderRadius double?
نصف قطر الزوايا
final
elevation double?
ارتفاع الشريط (الظل)
final
hashCode int
The hash code for this object.
no setterinherited
iconSize double?
حجم الأيقونات
final
padding EdgeInsetsGeometry?
الحشو الداخلي
final
position Alignment?
موضع الشريط في الشاشة (افتراضي: يمين المنتصف)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedBackgroundColor Color?
لون خلفية الأيقونة المحددة
final
selectedIconColor Color?
لون الأيقونة المحددة
final
showTooltip bool?
هل يظهر الـ tooltip عند الضغط المطوّل؟
final
spacing double?
المسافة بين الأزرار
final
tooltipBackgroundColor Color?
لون التلميحات (Tooltip)
final
tooltipTextStyle TextStyle?
نمط نص التلميح
final
unselectedIconColor Color?
لون الأيقونة غير المحددة
final

Methods

copyWith({Color? backgroundColor, Color? selectedIconColor, Color? unselectedIconColor, Color? selectedBackgroundColor, double? iconSize, double? borderRadius, EdgeInsetsGeometry? padding, double? spacing, double? elevation, Alignment? position, Color? tooltipBackgroundColor, TextStyle? tooltipTextStyle, bool? showTooltip}) DisplayModeBarStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited