copyWith method

DownloadFontsDialogStyle copyWith({
  1. Color? backgroundColor,
  2. String? defaultFontText,
  3. Color? dividerColor,
  4. String? downloadedFontsText,
  5. List<String>? recitationNames,
  6. Color? downloadButtonBackgroundColor,
  7. TextStyle? downloadingStyle,
  8. String? downloadingText,
  9. TextStyle? fontNameStyle,
  10. Color? iconColor,
  11. double? iconSize,
  12. Widget? iconWidget,
  13. Color? linearProgressBackgroundColor,
  14. Color? linearProgressColor,
  15. String? notes,
  16. Color? notesColor,
  17. TextStyle? notesStyle,
  18. String? title,
  19. Color? titleColor,
  20. TextStyle? titleStyle,
  21. String? headerTitle,
  22. Color? closeIconColor,
  23. Gradient? backgroundGradient,
  24. String? tajweedOptionNames,
})

Creates a copy of the current DownloadFontsDialogStyle instance with the specified properties replaced by new values.

This method allows you to create a modified version of the current style by providing new values for specific properties while keeping the rest unchanged.

Implementation

DownloadFontsDialogStyle copyWith({
  Color? backgroundColor,
  String? defaultFontText,
  Color? dividerColor,
  String? downloadedFontsText,
  List<String>? recitationNames,
  Color? downloadButtonBackgroundColor,
  TextStyle? downloadingStyle,
  String? downloadingText,
  TextStyle? fontNameStyle,
  Color? iconColor,
  double? iconSize,
  Widget? iconWidget,
  Color? linearProgressBackgroundColor,
  Color? linearProgressColor,
  String? notes,
  Color? notesColor,
  TextStyle? notesStyle,
  String? title,
  Color? titleColor,
  TextStyle? titleStyle,
  String? headerTitle,
  Color? closeIconColor,
  Gradient? backgroundGradient,
  String? tajweedOptionNames,
}) {
  return DownloadFontsDialogStyle(
      backgroundColor: backgroundColor ?? this.backgroundColor,
      defaultFontText: defaultFontText ?? this.defaultFontText,
      dividerColor: dividerColor ?? this.dividerColor,
      downloadedFontsText: downloadedFontsText ?? this.downloadedFontsText,
      recitationNames: recitationNames ?? this.recitationNames,
      downloadButtonBackgroundColor:
          downloadButtonBackgroundColor ?? this.downloadButtonBackgroundColor,
      downloadingStyle: downloadingStyle ?? this.downloadingStyle,
      downloadingText: downloadingText ?? this.downloadingText,
      fontNameStyle: fontNameStyle ?? this.fontNameStyle,
      iconColor: iconColor ?? this.iconColor,
      iconSize: iconSize ?? this.iconSize,
      iconWidget: iconWidget ?? this.iconWidget,
      linearProgressBackgroundColor:
          linearProgressBackgroundColor ?? this.linearProgressBackgroundColor,
      linearProgressColor: linearProgressColor ?? this.linearProgressColor,
      notes: notes ?? this.notes,
      notesColor: notesColor ?? this.notesColor,
      notesStyle: notesStyle ?? this.notesStyle,
      titleColor: titleColor ?? this.titleColor,
      titleStyle: titleStyle ?? this.titleStyle,
      headerTitle: headerTitle ?? this.headerTitle,
      closeIconColor: closeIconColor ?? this.closeIconColor,
      backgroundGradient: backgroundGradient ?? this.backgroundGradient,
      tajweedOptionNames: tajweedOptionNames ?? this.tajweedOptionNames);
}