defaultFontText property
The text to be displayed as the title for the default font.
Implementation
@Deprecated('استخدم recitationNames بدلًا من defaultFontText.')
final String? defaultFontText;
The text to be displayed as the title for the default font.
@Deprecated('استخدم recitationNames بدلًا من defaultFontText.')
final String? defaultFontText;