DualPageView class
وضع عرض صفحتين كاملتين جنبًا إلى جنب (شاشات كبيرة + أفقي)
يعرض صفحتين من المصحف جنبًا إلى جنب بدون تمرير عمودي. يُقيّد بالشاشات الكبيرة (تابلت/ديسكتوب) في الوضع الأفقي.
DualPageView Displays two Quran pages side-by-side without vertical scrolling. Restricted to large screens in landscape orientation.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DualPageView
- Available extensions
Constructors
-
DualPageView({Key? key, required QuranCtrl quranCtrl, required bool isDark, required String languageCode, required dynamic onPageChanged(int pageNumber)?, required VoidCallback? onPagePress, required Widget? circularProgressWidget, required List bookmarkList, required Color? ayahSelectedFontColor, required Color? textColor, required Color? ayahIconColor, required bool showAyahBookmarkedIcon, required void onAyahLongPress(LongPressStartDetails details, AyahModel ayah)?, required Color? bookmarksColor, required SurahNameStyle? surahNameStyle, required BannerStyle? bannerStyle, required BasmalaStyle? basmalaStyle, required void onSurahBannerPress(SurahNamesModel surah)?, required int? surahNumber, required Color? ayahSelectedBackgroundColor, required String? fontsName, required List<
int> ? ayahBookmarked, required bool isAyahBookmarked(AyahModel ayah)?, required BuildContext parentContext, required bool? isFontsLocal}) -
const
Properties
-
ayahBookmarked
→ List<
int> ? -
final
- ayahIconColor → Color?
-
final
- ayahSelectedBackgroundColor → Color?
-
final
- ayahSelectedFontColor → Color?
-
final
-
final
- basmalaStyle → BasmalaStyle?
-
final
- bookmarkList → List
-
final
- bookmarksColor → Color?
-
final
- circularProgressWidget → Widget?
-
final
- fontsName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAyahBookmarked → bool Function(AyahModel ayah)?
-
final
- isDark → bool
-
final
- isFontsLocal → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- languageCode → String
-
final
- onAyahLongPress → void Function(LongPressStartDetails details, AyahModel ayah)?
-
final
- onPageChanged → dynamic Function(int pageNumber)?
-
final
- onPagePress → VoidCallback?
-
final
- onSurahBannerPress → void Function(SurahNamesModel surah)?
-
final
- parentContext → BuildContext
-
final
- quranCtrl → QuranCtrl
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAyahBookmarkedIcon → bool
-
final
- surahNameStyle → SurahNameStyle?
-
final
- surahNumber → int?
-
final
- textColor → Color?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
fontSizeDropDown(
{double? height, Color? color, bool isDark = false, TafsirStyle? tafsirStyle}) → Widget -
Available on Widget, provided by the FontSizeExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showSajda(
BuildContext context, int pageIndex, String sajdaName, Color sajdaNameColor) → Widget -
Available on Widget, provided by the SajdaExtension extension
Displays a Sajda widget. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited