QiraatWordInfo class

Constructors

QiraatWordInfo({required int suraNumber, required String? suraName, required int ayaNumber, required int wordNumber, required String word, required String content, required bool hasKhilaf})
const
QiraatWordInfo.fromJson(Map<String, dynamic> json)
factory

Properties

ayaNumber int
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
hasKhilaf bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suraName String?
final
suraNumber int
final
word String
final
wordNumber int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited