QpcHafsWordByWordStore class

Constructors

QpcHafsWordByWordStore({required Map<int, String> textByKey})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textByKey Map<int, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textFor({required int surah, required int ayah, required int word}) String?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

key({required int surah, required int ayah, required int word}) int