QpcV4AyahLineBlock class

Inheritance

Constructors

QpcV4AyahLineBlock({required bool isCentered, required List<QpcV4WordSegment> segments})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isCentered bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<QpcV4WordSegment>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited