QpcV4RichTextLine class

Inheritance
Available extensions

Constructors

QpcV4RichTextLine({Key? key, required int pageIndex, required Color? textColor, required bool isDark, required Map<int, List<BookmarkModel>> bookmarks, required dynamic onAyahLongPress(LongPressStartDetails details, AyahModel ayah)?, required List? bookmarkList, required Color? ayahIconColor, required bool showAyahBookmarkedIcon, required List<int> bookmarksAyahs, required Color? bookmarksColor, required Color? ayahSelectedBackgroundColor, required BuildContext context, required QuranCtrl quranCtrl, required List<QpcV4WordSegment> segments, required bool isFontsLocal, required String fontsName, String? fontFamilyOverride, String? fontPackageOverride, bool usePaintColoring = true, required List<int> ayahBookmarked, bool isAyahBookmarked(AyahModel ayah)?, required bool isCentered})
const

Properties

ayahBookmarked List<int>
final
ayahIconColor Color?
final
ayahSelectedBackgroundColor Color?
final
bookmarkList List?
final
bookmarks Map<int, List<BookmarkModel>>
final
bookmarksAyahs List<int>
final
bookmarksColor Color?
final
context BuildContext
final
fontFamilyOverride String?
final
fontPackageOverride String?
final
fontsName String
final
hashCode int
The hash code for this object.
no setterinherited
isAyahBookmarked bool Function(AyahModel ayah)?
final
isCentered bool
final
isDark bool
final
isFontsLocal bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAyahLongPress → dynamic Function(LongPressStartDetails details, AyahModel ayah)?
final
pageIndex int
final
quranCtrl QuranCtrl
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<QpcV4WordSegment>
final
showAyahBookmarkedIcon bool
final
textColor Color?
final
usePaintColoring bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<QpcV4RichTextLine>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
fontSizeDropDown({double? height, Color? color, bool isDark = false, TafsirStyle? tafsirStyle}) Widget

Available on Widget, provided by the FontSizeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showSajda(BuildContext context, int pageIndex, String sajdaName, Color sajdaNameColor) Widget

Available on Widget, provided by the SajdaExtension extension

Displays a Sajda widget.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited