QpcV4Word class

Constructors

QpcV4Word({required int id, required int surah, required int ayah, required int wordIndex, required String text})
const
QpcV4Word.fromJson(Map<String, dynamic> json)
factory

Properties

ayah int
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surah int
final
text String
final
wordIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited