isShowTabBar property
لتحديد ما إذا كان يجب عرض شريط التبويب أم لا isShowTabBar To specify whether to show the tab bar or not
Implementation
final bool? isShowTabBar;
لتحديد ما إذا كان يجب عرض شريط التبويب أم لا isShowTabBar To specify whether to show the tab bar or not
final bool? isShowTabBar;