SurahPageViewBuild class
ويدجت لعرض صفحة واحدة ضمن شاشة "سورة واحدة" فقط.
الهدف: عرض آيات السورة المحددة فقط حتى لو كانت صفحة المصحف تحتوي على أكثر من سورة.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SurahPageViewBuild
- Available extensions
Constructors
-
SurahPageViewBuild({Key? key, required BuildContext userContext, required QuranPageModel surahPage, required int surahPageIndex, required int globalPageIndex, required int surahNumber, required bool isDark, required String? languageCode, Widget? circularProgressWidget, List? bookmarkList, Color? bookmarksColor, Color? textColor, Color? ayahSelectedFontColor, Color? ayahSelectedBackgroundColor, Color? ayahIconColor, bool showAyahBookmarkedIcon = true, List<
int> ayahBookmarked = const [], bool isAyahBookmarked(AyahModel ayah)?, void onAyahLongPress(LongPressStartDetails details, AyahModel ayah)?, void onSurahBannerPress(SurahNamesModel surah)?, BannerStyle? bannerStyle, SurahNameStyle? surahNameStyle, BasmalaStyle? basmalaStyle}) -
const
Properties
-
ayahBookmarked
→ List<
int> -
final
- ayahIconColor → Color?
-
final
- ayahSelectedBackgroundColor → Color?
-
final
- ayahSelectedFontColor → Color?
-
final
-
final
- basmalaStyle → BasmalaStyle?
-
final
- bookmarkList → List?
-
final
- bookmarksColor → Color?
-
final
- circularProgressWidget → Widget?
-
final
- globalPageIndex → int
-
Index عالمي (0-based) لصفحة المصحف الحقيقي لاستخدامه في Top/Bottom
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAyahBookmarked → bool Function(AyahModel ayah)?
-
final
- isDark → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- languageCode → String?
-
final
- onAyahLongPress → void Function(LongPressStartDetails details, AyahModel ayah)?
-
final
- onSurahBannerPress → void Function(SurahNamesModel surah)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAyahBookmarkedIcon → bool
-
final
- surahNameStyle → SurahNameStyle?
-
final
- surahNumber → int
-
final
- surahPage → QuranPageModel
-
final
- surahPageIndex → int
-
Index داخل قائمة صفحات السورة (surahCtrl.surahPages)
final
- textColor → Color?
-
final
- userContext → BuildContext
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
fontSizeDropDown(
{double? height, Color? color, bool isDark = false, TafsirStyle? tafsirStyle}) → Widget -
Available on Widget, provided by the FontSizeExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showSajda(
BuildContext context, int pageIndex, String sajdaName, Color sajdaNameColor) → Widget -
Available on Widget, provided by the SajdaExtension extension
Displays a Sajda widget. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited