TajweedMenuStyle class

نمط تخصيص نافذة/قائمة أحكام التجويد.

يُستخدم هذا النمط لضبط أبعاد الحاوية، ألوان الخلفية والنص، ترويسة النافذة (العنوان/الأيقونة/الخلفية المتدرجة) وتنسيق عناصر القائمة.

Constructors

TajweedMenuStyle({double? width, double? height, EdgeInsetsGeometry? containerPadding, Color? backgroundColor, double? borderRadius, EdgeInsetsGeometry? headerPadding, String? headerTitle, Color? headerTitleColor, Color? headerCloseIconColor, Gradient? headerBackgroundGradient, EdgeInsetsGeometry? listMargin, EdgeInsets? listPadding, double? listBorderRadius, EdgeInsetsGeometry? itemMargin, EdgeInsetsGeometry? itemPadding, double? itemBorderRadius, Color? itemBorderColor, double? itemBorderWidth, double? itemGradientOpacity, double? swatchSize, double? swatchBorderRadius, TextStyle? itemTextStyle})
const
TajweedMenuStyle.defaults({required bool isDark, required BuildContext context})
قيم افتراضية متناسقة مع الوضع (ليلي/نهاري)
factory

Properties

backgroundColor Color?
final
borderRadius double?
final
containerPadding EdgeInsetsGeometry?
final
hashCode int
The hash code for this object.
no setterinherited
headerBackgroundGradient Gradient?
final
headerCloseIconColor Color?
final
headerPadding EdgeInsetsGeometry?
final
headerTitle String?
final
headerTitleColor Color?
final
height double?
final
itemBorderColor Color?
final
itemBorderRadius double?
final
itemBorderWidth double?
final
itemGradientOpacity double?
final
itemMargin EdgeInsetsGeometry?
final
itemPadding EdgeInsetsGeometry?
final
itemTextStyle TextStyle?
final
listBorderRadius double?
final
listMargin EdgeInsetsGeometry?
final
listPadding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swatchBorderRadius double?
final
swatchSize double?
final
width double?
final

Methods

copyWith({double? width, double? height, EdgeInsetsGeometry? containerPadding, Color? backgroundColor, double? borderRadius, EdgeInsetsGeometry? headerPadding, String? headerTitle, Color? headerTitleColor, Color? headerCloseIconColor, Gradient? headerBackgroundGradient, EdgeInsetsGeometry? listMargin, EdgeInsets? listPadding, double? listBorderRadius, EdgeInsetsGeometry? itemMargin, EdgeInsetsGeometry? itemPadding, double? itemBorderRadius, Color? itemBorderColor, double? itemBorderWidth, double? itemGradientOpacity, double? swatchSize, double? swatchBorderRadius, TextStyle? itemTextStyle}) TajweedMenuStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited