WordInfoCtrl class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • WordInfoCtrl
Implemented types
Mixed-in types
  • GetSingleTickerProviderStateMixin

Constructors

WordInfoCtrl({WordInfoRepository? repository})

Properties

downloadingKind → Rx<WordInfoKind?>
final
downloadProgress → RxDouble
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDownloading → RxBool
final
isPreparingDownload → RxBool
final
isTenRecitations bool
no setter
isWordAudioInitialized bool
هل تمت تهيئة خدمة صوت الكلمات (OAuth2 credentials)؟
no setter
isWordSelectionEnabled bool
تفعيل/تعطيل تحديد الكلمة وعرض الـ BottomSheet يُضبط من خلال بارامتر QuranLibraryScreen.enableWordSelection
getter/setter pair
listeners int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
recitationsDataRevision int
رقم مراجعة (revision) يتغير عند وصول/تغير بيانات القراءات في الذاكرة. يُستخدم لإبطال كاش عرض سطور QPC v4 عند اكتمال prewarm.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedKind → Rx<WordInfoKind>
final
selectedWordRef → Rx<WordRef?>
final
tabController TabController
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
clearSelectedWord() → void
createTicker(TickerCallback onTick) Ticker
Creates a ticker with the given callback.
inherited
didChangeDependencies(BuildContext context) → void
inherited
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
downloadKind(WordInfoKind kind) Future<void>
getRecitationsInfo(WordRef ref) Future<QiraatWordInfo?>
getRecitationsInfoSync(WordRef ref) QiraatWordInfo?
getWordInfo({required WordInfoKind kind, required WordRef ref}) Future<QiraatWordInfo?>
isKindAvailable(WordInfoKind kind) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
override
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
playAyahWordsAudio(WordRef ref) Future<void>
تشغيل كل كلمات الآية بالتسلسل.
playWordAudio(WordRef ref) Future<void>
تشغيل صوت كلمة واحدة.
prewarmRecitationsSurah(int surahNumber) Future<void>
prewarmRecitationsSurahs(Iterable<int> surahNumbers) Future<void>
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
setSelectedKind(WordInfoKind kind) → void
setSelectedWord(WordRef ref) → void
stopWordAudio() Future<void>
إيقاف صوت الكلمات.
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance WordInfoCtrl
no setter