WordRef class

Constructors

WordRef({required int surahNumber, required int ayahNumber, required int wordNumber})
const

Properties

ayahNumber int
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surahNumber int
final
wordNumber int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override