quran_library library

Classes

ActualTafsirWidget
AndroidAudioOffloadPreferences
Audio offload preferences for Android.
AndroidContentStyle
Key/value codes for use in MediaItem.extras and AudioServiceConfig.androidBrowsableRootExtras to influence how Android Auto will style browsable and playable media items.
AndroidEqualizer
An AudioEffect for Android that can adjust the gain for different frequency bands of an AudioPlayer's audio signal.
AndroidEqualizerBand
A frequency band within an AndroidEqualizer.
AndroidEqualizerParameters
The parameter values of an AndroidEqualizer.
AndroidExtractorOptions
AndroidLivePlaybackSpeedControl
Speed control for live streams on Android.
AndroidLoadControl
Buffering and loading options for Android.
AndroidLoudnessEnhancer
An Android AudioEffect that boosts the volume of the audio signal to a target gain, which defaults to zero.
AndroidPlaybackInfo
Information about volume control for either local or remote playback depending on the subclass.
AndroidVolumeDirection
An enum of volume direction controls on Android.
AppBarWidget
AssetsPath
AudioCtrl
AudioEffect
Subclasses of AudioEffect can be inserted into an AudioPipeline to modify the audio signal outputted by an AudioPlayer. The same audio effect instance cannot be set on multiple players at the same time.
AudioHandler
AudioLoadConfiguration
Configuration options to use when loading audio from a source.
AudioPipeline
THe pipeline of audio effects to be appliet to an AudioPlayer.
AudioPlayer
An audio player that plays a gapless playlist of AudioSources.
AudioService
Provides an API to manage the app's AudioHandler. An app must call init during initialisation to register the AudioHandler that will service all requests to play audio.
AudioServiceBackground
This class is deprecated. Use the stream subjects in BaseAudioHandler instead.
AudioServiceConfig
The configuration options to use when intializing the AudioService.
AudioServiceWidget
This widget is no longer required and has been deprecated.
AudioSource
Specifies a source of audio to be played. Audio sources are composable using the subclasses of this class. The same AudioSource instance should not be used simultaneously by more than one AudioPlayer.
AudioSurahNameWidget
AyahAudioStyle
AyahChangeReader
AyahDownloadManagerSheet
BottomSheet احترافي لإدارة تحميل/حذف آيات السور حسب القارئ الحالي
AyahDownloadManagerStyle
AyahLongClickTheme
مزود نمط حوار الضغط المطوّل على الآية
AyahMenuDialog
A dialog displayed on long click of an Ayah to provide options like bookmarking and copying text.
AyahMenuStyle
نمط مخصص لحوار الضغط المطوّل على الآية (AyahLongClickDialog).
AyahModel
موديل موحد للآية في القرآن يدعم كل من بيانات الخطوط الأصلية والمنزلة Unified Ayah model for both original and downloaded fonts data
AyahsAudioWidget
AyahSkipToNext
AyahSkipToPrevious
BackgroundAudioTask
This class is deprecated. Use BaseAudioHandler instead.
BannerStyle
BaseAudioHandler
Base class for implementations of AudioHandler. It provides default implementations of all methods and streams. Each stream in this class is specialized as either a BehaviorSubject or PublishSubject providing an additional add method for emitting values on those streams.
BasmalaStyle
A class that represents the style for Basmala text in the application.
BasmallahWidget
A widget that displays the Basmallah (بِسْمِ ٱللَّٰهِ ٱلرَّحْمَٰنِ ٱلرَّحِيمِ).
BookmarkModel
A model class that represents a single bookmark in the Quran.
BookmarksAyahs
A model class that represents a single bookmark in the Quran.
BookmarksCtrl
Controller that handles the bookmarks of the user.
BookmarksTabStyle
فئة لتخصيص أنماط واجهة تبويب الفواصل Class for customizing Bookmarks Tab styles
BookmarksTabTheme
مزود نمط تبويب العلامات المرجعية (Bookmarks)
BuildBottomSection
BuildEnhancedSurahItem
BuildTopSection
ChangeTafsirDialog
ClippingAudioSource
An AudioSource that clips the audio of a UriAudioSource between a certain start and end time.
CompositeAudioHandler
A CompositeAudioHandler wraps another AudioHandler and adds additional behaviour to it. Each method will by default pass through to the corresponding method of the wrapped handler. If you override a method, it must call super in addition to any "additional" functionality you add.
ConcatenatingAudioSource
An AudioSource representing a concatenation of multiple audio sources to be played in succession. This can be used to create playlists. Playback between items will be gapless on Android, iOS and macOS, while there will be a slight gap on Web.
CurvyArrowButton
CurvyArrowPainter
CustomMediaAction
Custom action information used to define an action name and optional extras that are sent to AudioHandler.customAction when the associated media control is used.
CustomTafsirEntry
CustomWidgets
DailogBuild
DarwinAssetOptions
DarwinLoadControl
Buffering and loading options for iOS/macOS.
DashAudioSource
An AudioSource representing a DASH stream. The following URI schemes are supported:
DefaultFirstTwoSurahs
DefaultFontsBuild
DefaultFontsPageBuild
DefaultOtherSurahs
DefaultShuffleOrder
The default implementation of ShuffleOrder which shuffles items with the currently playing item at the head of the order.
DownloadedAndDeleteWidget
DownloadedTextWidget
DownloadFontsDialogStyle
A class that defines the style for the download fonts dialog.
FontLoaderIsolateManager
كلاس مساعد ساكن لإدارة حالة Isolate تحميل الخطوط
FontLoadMessage
رسالة تُرسل إلى Isolate لتحميل خط
FontsDownloadDialog
GetSingleAyah
HeaderBuild
HlsAudioSource
An AudioSource representing an HLS stream. The following URI schemes are supported:
IcyHeaders
IcyInfo
IcyMetadata
IndexedAudioSource
An AudioSource that can appear in a sequence.
IndexTabStyle
نمط مخصص لتبويب الفهرس (السور/الأجزاء) داخل شريط القرآن. يتيح تخصيص الألوان والأبعاد والأنماط النصية والعناوين.
IndexTabTheme
مزود نمط تبويب الفهرس
IsolatedAudioHandler
A CompositeAudioHandler that can be accessed from other isolates via lookup.
JumpingPageControllerWidget
JustAudioMediaKit
LineModel
هذا الموديل يمثل سطر في صفحة القرآن ويحتوي على قائمة من الآيات الموحدة This model represents a line in a Quran page and contains a list of unified ayahs
LocalAndroidPlaybackInfo
Playback information for local volume handling.
LockCachingAudioSource
This is an experimental audio source that caches the audio while it is being downloaded and played. It is not supported on platforms that do not provide access to the file system (e.g. web).
LoopingAudioSource
MediaControl
A button to appear in the Android notification, lock screen, Android smart watch, or Android Auto device. The set of buttons you would like to display at any given moment should be streamed via AudioHandler.playbackState.
MediaItem
Metadata of an audio item that can be played, or a folder containing audio items.
MediaItemCopyWith
The copyWith function type for MediaItem.
PackagePositionData
PackageSliderWidget
PageBuild
PageFontSizeHelper
Helpers to compute dynamic font sizes for Quran pages across devices.
PageViewBuild
PlayAyahWidget
PlaybackEvent
Encapsulates the playback state and current position of the player.
PlaybackState
The playback state which includes a playing boolean state, a processing state such as AudioProcessingState.buffering, the playback position and the currently enabled actions to be shown in the Android notification or the iOS control center.
PlaybackStateCopyWith
The copyWith function type for PlaybackState.
PlayerEvent
Encapsulates the playback event and the playing state of the player.
PlayerState
Encapsulates the playing and processing states. These two states vary orthogonally, and so if processingState is ProcessingState.buffering, you can check playing to determine whether the buffering occurred while the player was playing or while the player was paused.
PlaySurahsWidget
PortraitWidget
PositionDiscontinuity
Information collected when a position discontinuity occurs.
ProgressIndicatorWidget
ProgressiveAudioSource
An AudioSource representing a regular media file such as an MP3 or M4A file. The following URI schemes are supported:
ProgressiveAudioSourceOptions
QuranCtrl
QuranLibrary
A class that provides utility functions for interacting with the Quran library.
QuranLibraryScreen
A widget that displays the Quran library screen.
QuranLibraryTheme
غلاف مركزي يحقن مزوِّدات أنماط متعددة بشكل مستقل لتقليل إعادة البناء
QuranPageModel
هذا الموديل يمثل صفحة من صفحات القرآن ويحتوي على قائمة من الآيات (AyahModel) والأسطر (LineModel) This model represents a Quran page and contains a list of ayahs (AyahModel) and lines (LineModel)
QuranPagesScreen
شاشة لعرض صفحة واحدة أو مجموعة صفحات محددة من المصحف
QuranRepository
A repository class for managing Quran-related data.
QuranState
QuranTopBarStyle
Style configuration for Quran Top Bar (previously DefaultDrawer) Allows customizing colors, texts, spacings, and icons
QuranTopBarTheme
مزود نمط الشريط العلوي للمصحف
Rating
A rating to attach to a MediaItem.
ReaderListBuild
ReadersConstants
RemoteAndroidPlaybackInfo
Playback information for remote volume handling.
RichTextBuild
SajdaFontsModel
SearchTabStyle
نمط مخصص لتبويب البحث داخل مكتبة القرآن.
SearchTabTheme
مزود نمط تبويب البحث
SequenceState
Encapsulates the sequence and currentIndex state and ensures consistency such that currentIndex is within the range of sequence.length. If sequence.length is 0, then currentIndex is also 0.
ShowTafseer
ShuffleOrder
Defines the algorithm for shuffling the order of a playlist. See DefaultShuffleOrder for a default implementation.
SilenceAudioSource
An AudioSource for a period of silence.
SnackBarStyle
نمط مخصص للـ SnackBar
SnackBarTheme
مزود نمط SnackBar
StorageConstants
StreamAudioResponse
The response for a StreamAudioSource. This API is experimental.
StreamAudioSource
An AudioSource that provides audio dynamically. Subclasses must override request to provide the encoded audio data. This API is experimental.
SurahAudioList
قائمة السور الصوتية مع دعم تمرير الألوان والأنماط Audio Surah list with color and style passing support
SurahAudioScreen
SurahAudioStyle
فئة لتخصيص أنماط واجهة تشغيل السور الصوتية Class for customizing Surah audio interface styles
SurahBackDropWidget
ويدجت خلفية تشغيل الصوت مع تصميم متجاوب للوضعين الأفقي والعمودي Background widget for audio playback with responsive design for portrait and landscape orientations
SurahChangeSurahReader
SurahCollapsedPlayWidget
SurahCtrl
كنترولر مخصص لعرض سورة واحدة بنفس تصميم QuranCtrl Dedicated controller for displaying a single surah with the same design as QuranCtrl
SurahDisplayScreen
شاشة لعرض سورة واحدة باستخدام SurahCtrl و _QuranLinePage Screen for displaying a single surah using SurahCtrl and _QuranLinePage
SurahDownloadPlayButton
SurahHeaderWidget
SurahInfoStyle
SurahInfoTheme
مزود نمط معلومات السورة (الأسفلية)
SurahLastListen
ويدجت آخر استماع مع دعم تمرير الألوان والأنماط Last listen widget with color and style passing support
SurahModel
موديل موحد للسورة يربط مع AyahModel Unified Surah model linked with AyahModel
SurahNamesModel
SurahNameStyle
A class that defines the style for a Surah name.
SurahOnlinePlayButton
SurahPlayLandscapeWidget
SurahRepeatWidget
SurahResponseModel
SurahSeekBar
SurahSkipToNext
SurahSkipToPrevious
SurahState
SwitchAudioHandler
A SwitchAudioHandler wraps another AudioHandler that may be switched for another at any time by setting inner.
TafsirCtrl
TafsirItemWidget
TafsirNameModel
TafsirPagesBuild
TafsirStyle
TafsirTableData
TafsirTheme
مزود نمط التفسير
TextScaleRichTextBuild
ToastUtils
TopAndBottomWidget
ويدجت لعرض محتوى السورة المخصصة مع المعلومات المطلوبة Widget for displaying custom surah content with required information
TopBottomQuranStyle
نمط مخصص لقسمَي أعلى/أسفل الصفحة (Top/Bottom) في المصحف.
TopBottomTheme
مزود نمط قسمَي الأعلى/الأسفل (Top/Bottom)
TranslationModel
TranslationsModel
UriAudioSource
An abstract class representing audio sources that are loaded from a URI.

Enums

AndroidAudioOffloadMode
Audio offload modes for Android.
AndroidVolumeControlType
An enumeration of different volume control types on Android.
AudioProcessingState
The states of audio processing.
AudioServiceRepeatMode
The available repeat modes.
AudioServiceShuffleMode
The available shuffle modes for the queue.
LoopMode
An enumeration of modes that can be passed to AudioPlayer.setLoopMode.
MediaAction
The actions associated with playing audio.
MediaButton
The buttons on a headset.
PositionDiscontinuityReason
The reasons for position discontinuities.
ProcessingState
Enumerates the different processing states of a player.
RatingStyle
The style of a Rating.
TafsirFileType
WebCrossOrigin
Possible values that can be passed to AudioPlayer.setWebCrossOrigin.

Mixins

AndroidAudioEffect
An AudioEffect that supports Android.
DarwinAudioEffect
An AudioEffect that supports iOS and macOS.
QueueHandler
This mixin provides default implementations of methods for updating and navigating the queue. When using this mixin, you must add a list of MediaItems to queue, override skipToQueueItem and initialise the queue index (e.g. by calling skipToQueueItem with the initial queue index). The skipToNext and skipToPrevious default implementations are defined by this mixin in terms of your own implementation of skipToQueueItem.
SeekHandler
This mixin provides default implementations of fastForward, rewind, seekForward and seekBackward which are all defined in terms of your own implementation of seek.

Extensions

AudioServiceValueStream on ValueStream<T>
(Maybe) temporary.
AyahCtrlExtension on AudioCtrl
ContextExtensions on BuildContext
Extension on BuildContext to provide additional utility methods.
ConvertArabicToEnglishNumbersExtension on String
Extension to convert Arabic numerals to English numerals and vice versa.
ConvertNumberExtension on String
An extension on the String class to convert numbers in the string according to the specified language code.
DownloadExtension on TafsirCtrl
FontsDownloadWidgetExtension on QuranCtrl
Extension on QuranCtrl to provide additional functionality related to fonts download widget.
FontsExtension on QuranCtrl
مُعرّف جيل لتحميل الخطوط يُستخدم لإلغاء دفعات قديمة عند تغيّر الصفحة بسرعة Generation token to cancel outdated preloading batches when page changes quickly Extension to handle font-related operations for the QuranCtrl class.
FontSizeExtension on Widget
QuranGetters on QuranCtrl
Extensions on QuranCtrl that provides getters for QuranCtrl's properties.
SajdaExtension on Widget
An extension on the Widget class to provide additional functionality related to Sajda (prostration) in the context of the Quran library.
ShowTafsirExtension on void
SplitBetweenExtension on List<T>
StringExtension on String
StringExtensions on String
Extension on the String class to provide additional utility methods.
SurahAudioStorage on AudioCtrl
SurahCtrlExtension on AudioCtrl
SurahGetters on AudioCtrl
SurahInfoExtension on void
An extension on the void type to provide additional functionality related to Surah information.
SurahUi on AudioCtrl
TafsirUi on TafsirCtrl
TextSpanExtension on String

Constants

rtlLang → const List<String>

Properties

tafsirNavigatorKey GlobalKey<NavigatorState>
GlobalKey للوصول إلى سياق التطبيق الرئيسي كحل طوارئ GlobalKey to access main app context as emergency solution
final

Functions

fontLoaderIsolate(SendPort sendPort) → void
نقطة دخول Isolate لتحميل الخطوط

Typedefs

AyahCountTextBuilder = String Function(int downloaded, int total)

Exceptions / Errors

PlayerException
Captures the details of any error accessing, loading or playing an audio source, including an invalid or inaccessible URL, or an audio encoding that could not be understood.
PlayerInterruptedException
An error that occurs when one operation on the player has been interrupted (e.g. by another simultaneous operation).