QpcHafsWordByWordStore class
Constructors
-
QpcHafsWordByWordStore({required Map<
int, String> textByKey}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
textFor(
{required int surah, required int ayah, required int word}) → String? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited