showWordInfo method
Future<void>
showWordInfo({
- required BuildContext context,
- required WordRef ref,
- WordInfoKind initialKind = WordInfoKind.recitations,
- bool isDark = false,
///////// Word Info ////////////
فتح نافذة معلومات الكلمة (Word Info) وتحميل البيانات عند الحاجة.
ref مرجع الكلمة (سورة/آية/رقم كلمة).
initialKind التبويب الذي تريد فتحه أولاً (القراءات/التصريف/الإعراب).
Opens the Word Info bottom sheet and allows downloading data on demand.
ref The word reference (surah/ayah/word).
initialKind The initial tab to open (recitations/tasreef/eerab).
مثال للاستخدام / Example usage:
await QuranLibrary().showWordInfo(
context: context,
ref: const WordRef(surahNumber: 1, ayahNumber: 1, wordNumber: 1),
initialKind: WordInfoKind.recitations,
isDark: true,
);
Implementation
/// فتح نافذة معلومات الكلمة (Word Info) وتحميل البيانات عند الحاجة.
///
/// [ref] مرجع الكلمة (سورة/آية/رقم كلمة).
/// [initialKind] التبويب الذي تريد فتحه أولاً (القراءات/التصريف/الإعراب).
///
/// Opens the Word Info bottom sheet and allows downloading data on demand.
///
/// [ref] The word reference (surah/ayah/word).
/// [initialKind] The initial tab to open (recitations/tasreef/eerab).
///
/// مثال للاستخدام / Example usage:
/// ```dart
/// await QuranLibrary().showWordInfo(
/// context: context,
/// ref: const WordRef(surahNumber: 1, ayahNumber: 1, wordNumber: 1),
/// initialKind: WordInfoKind.recitations,
/// isDark: true,
/// );
/// ```
Future<void> showWordInfo({
required BuildContext context,
required WordRef ref,
WordInfoKind initialKind = WordInfoKind.recitations,
bool isDark = false,
}) async {
await showWordInfoBottomSheet(
context: context,
ref: ref,
initialKind: initialKind,
isDark: isDark,
);
}