WordAudioService class
خدمة تشغيل صوت الكلمات (word-by-word) من CDN.
الملفات الصوتية متاحة على https://audio.qurancdn.com/wbw/{sss}_{aaa}_{www}.mp3
بدون حاجة لمصادقة.
يجب استدعاء init مرة واحدة قبل الاستخدام:
QuranLibrary.initWordAudio();
Properties
-
currentPlayingRef
→ Rx<
WordRef?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
no setter
- isLoading → RxBool
-
final
- isPlaying → RxBool
-
final
- isPlayingAyahWords → RxBool
-
true إذا يتم تشغيل كلمات آية كاملة (وليس كلمة واحدة فقط)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - تنظيف الموارد.
-
getAyahWordCount(
int surahNumber, int ayahNumber) → int - حساب عدد الكلمات الفعلية (بدون end marker) في آية معيّنة باستخدام بيانات QPC v4 المحمّلة.
-
init(
) → void - تفعيل خدمة صوت الكلمات.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
playAyahWords(
{required int surahNumber, required int ayahNumber, int? totalWords}) → Future< void> - تشغيل كل كلمات آية بالتسلسل.
-
playWord(
WordRef ref) → Future< void> - تشغيل كلمة واحدة.
-
stop(
) → Future< void> - إيقاف التشغيل.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → WordAudioService
-
no setter