WordInfoBottomSheetStyle class
Style configuration for Word Info bottom sheet.
This matches the pattern used across the library styles:
- nullable fields for overrides
copyWithfor partial updatesdefaultsfactory based onisDark+context
Constructors
- WordInfoBottomSheetStyle({Color? backgroundColor, double? borderRadius, EdgeInsetsGeometry? padding, double? maxHeightFactor, double? maxWidthFactor, double? handleWidth, double? handleHeight, EdgeInsetsGeometry? handleMargin, double? handleBorderRadius, Color? handleColor, String? titleText, TextStyle? titleTextStyle, EdgeInsetsGeometry? titlePadding, String? tabRecitationsText, String? tabTasreefText, String? tabEerabText, String? downloadText, String? downloadingText, String? loadErrorText, String? noDataText, TextStyle? tabLabelStyle, EdgeInsetsGeometry? tabIndicatorPadding, double? tabIndicatorRadius, Color? tabIndicatorColor, double? dividerHeight, EdgeInsetsGeometry? contentPadding, TextStyle? bodyTextStyle, TextStyle? buttonTextStyle, TextStyle? progressTextStyle, double? verticalMargin, double? horizontalMargin, EdgeInsetsGeometry? innerContainerPadding, Color? tafsirBackgroundColor, double? innerContainerBorderRadius, Color? innerShadowColor, double? innerShadowBlurRadius, Offset? innerShadowOffset, Color? innerBorderColor, double? innerBorderWidth, Color? textBackgroundColor, Widget? handleWidget, Color? audioButtonColor, Color? audioButtonActiveColor, double? audioButtonSize, String? playWordTooltip, String? playAyahWordsTooltip})
-
const
- WordInfoBottomSheetStyle.defaults({required bool isDark, required BuildContext context})
-
factory
Properties
- audioButtonActiveColor → Color?
-
final
- audioButtonColor → Color?
-
final
- audioButtonSize → double?
-
final
- backgroundColor → Color?
-
final
- bodyTextStyle → TextStyle?
-
final
- borderRadius → double?
-
final
-
final
- contentPadding → EdgeInsetsGeometry?
-
final
- dividerHeight → double?
-
final
- downloadingText → String?
-
final
- downloadText → String?
-
final
- handleBorderRadius → double?
-
final
- handleColor → Color?
-
final
- handleHeight → double?
-
final
- handleMargin → EdgeInsetsGeometry?
-
final
- handleWidget → Widget?
-
final
- handleWidth → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalMargin → double?
-
final
- innerBorderColor → Color?
-
final
- innerBorderWidth → double?
-
final
- innerContainerBorderRadius → double?
-
final
- innerContainerPadding → EdgeInsetsGeometry?
-
final
- innerShadowBlurRadius → double?
-
final
- innerShadowColor → Color?
-
final
- innerShadowOffset → Offset?
-
final
- loadErrorText → String?
-
final
- maxHeightFactor → double?
-
Bottom sheet constraints as factors of screen size.
final
- maxWidthFactor → double?
-
final
- noDataText → String?
-
final
- padding → EdgeInsetsGeometry?
-
final
- playAyahWordsTooltip → String?
-
final
- playWordTooltip → String?
-
final
- progressTextStyle → TextStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabEerabText → String?
-
final
- tabIndicatorColor → Color?
-
final
- tabIndicatorPadding → EdgeInsetsGeometry?
-
final
- tabIndicatorRadius → double?
-
final
- tabLabelStyle → TextStyle?
-
final
- tabRecitationsText → String?
-
final
- tabTasreefText → String?
-
final
- tafsirBackgroundColor → Color?
-
final
- textBackgroundColor → Color?
-
final
- titlePadding → EdgeInsetsGeometry?
-
final
- titleText → String?
-
final
- titleTextStyle → TextStyle?
-
final
-
final
- verticalMargin → double?
-
final
Methods
-
copyWith(
{Color? backgroundColor, double? borderRadius, EdgeInsetsGeometry? padding, double? maxHeightFactor, double? maxWidthFactor, double? handleWidth, double? handleHeight, EdgeInsetsGeometry? handleMargin, double? handleBorderRadius, Color? handleColor, String? titleText, TextStyle? titleTextStyle, EdgeInsetsGeometry? titlePadding, String? tabRecitationsText, String? tabTasreefText, String? tabEerabText, String? downloadText, String? downloadingText, String? loadErrorText, String? noDataText, TextStyle? tabLabelStyle, EdgeInsetsGeometry? tabIndicatorPadding, double? tabIndicatorRadius, Color? tabIndicatorColor, double? dividerHeight, EdgeInsetsGeometry? contentPadding, TextStyle? bodyTextStyle, TextStyle? buttonTextStyle, TextStyle? progressTextStyle, double? verticalMargin, double? horizontalMargin, EdgeInsetsGeometry? innerContainerPadding, Color? tafsirBackgroundColor, double? innerContainerBorderRadius, Color? innerShadowColor, double? innerShadowBlurRadius, Offset? innerShadowOffset, Color? innerBorderColor, double? innerBorderWidth, Color? textBackgroundColor, Widget? handleWidget, Color? audioButtonColor, Color? audioButtonActiveColor, double? audioButtonSize, String? playWordTooltip, String? playAyahWordsTooltip}) → WordInfoBottomSheetStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited