WordInfoRepository class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
downloadKind(
{required WordInfoKind kind, required ZipDownloadProgressCallback onProgress}) → Future< void> -
getRecitationWordInfoSync(
{required WordRef ref}) → QiraatWordInfo? -
getWordInfo(
{required WordInfoKind kind, required WordRef ref}) → Future< QiraatWordInfo?> -
isKindDownloaded(
WordInfoKind kind) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prewarmRecitationsSurah(
int surahNumber) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited