ZipDownloadService class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
downloadAndExtract(
{required List< String> urls, required File zipFile, required Directory destinationDir, required ZipDownloadProgressCallback onProgress, Duration connectTimeout = const Duration(seconds: 20), Duration receiveTimeout = const Duration(minutes: 2), Map<String, String> ? headers, int minZipSizeBytes = 1024 * 1024, String logName = 'ZipDownload'}) → Future<void>