Subclasses of AudioEffect can be inserted into an AudioPipeline to
modify the audio signal outputted by an AudioPlayer. The same audio effect
instance cannot be set on multiple players at the same time.
Provides an API to manage the app's AudioHandler. An app must call init
during initialisation to register the AudioHandler that will service all
requests to play audio.
Specifies a source of audio to be played. Audio sources are composable
using the subclasses of this class. The same AudioSource instance should
not be used simultaneously by more than one AudioPlayer.
Base class for implementations of AudioHandler. It provides default
implementations of all methods and streams. Each stream in this class is
specialized as either a BehaviorSubject or PublishSubject providing an
additional add method for emitting values on those streams.
A CompositeAudioHandler wraps another AudioHandler and adds additional
behaviour to it. Each method will by default pass through to the
corresponding method of the wrapped handler. If you override a method, it
must call super in addition to any "additional" functionality you add.
An AudioSource representing a concatenation of multiple audio sources to
be played in succession. This can be used to create playlists. Playback
between items will be gapless on Android, iOS and macOS, while there will
be a slight gap on Web.
Custom action information used to define an action name and optional extras
that are sent to AudioHandler.customAction when the associated media control is used.
هذا الموديل يمثل سطر في صفحة القرآن ويحتوي على قائمة من الآيات الموحدة
This model represents a line in a Quran page and contains a list of unified ayahs
This is an experimental audio source that caches the audio while it is being
downloaded and played. It is not supported on platforms that do not provide
access to the file system (e.g. web).
A button to appear in the Android notification, lock screen, Android smart
watch, or Android Auto device. The set of buttons you would like to display
at any given moment should be streamed via AudioHandler.playbackState.
The playback state which includes a playing boolean state, a processing
state such as AudioProcessingState.buffering, the playback position and
the currently enabled actions to be shown in the Android notification or the
iOS control center.
Encapsulates the playing and processing states. These two states vary
orthogonally, and so if processingState is ProcessingState.buffering,
you can check playing to determine whether the buffering occurred while
the player was playing or while the player was paused.
هذا الموديل يمثل صفحة من صفحات القرآن ويحتوي على قائمة من الآيات (AyahModel) والأسطر (LineModel)
This model represents a Quran page and contains a list of ayahs (AyahModel) and lines (LineModel)
Encapsulates the sequence and currentIndex state and ensures
consistency such that currentIndex is within the range of
sequence.length. If sequence.length is 0, then currentIndex is also
0.
ويدجت خلفية تشغيل الصوت مع تصميم متجاوب للوضعين الأفقي والعمودي
Background widget for audio playback with responsive design for portrait and landscape orientations
This mixin provides default implementations of methods for updating and
navigating the queue. When using this mixin, you must add a list of
MediaItems to queue, override skipToQueueItem and initialise the queue
index (e.g. by calling skipToQueueItem with the initial queue index). The
skipToNext and skipToPrevious default implementations are defined by
this mixin in terms of your own implementation of skipToQueueItem.
مُعرّف جيل لتحميل الخطوط يُستخدم لإلغاء دفعات قديمة عند تغيّر الصفحة بسرعة
Generation token to cancel outdated preloading batches when page changes quickly
Extension to handle font-related operations for the QuranCtrl class.
Captures the details of any error accessing, loading or playing an audio
source, including an invalid or inaccessible URL, or an audio encoding that
could not be understood.